@@ -1,10 +1,10 @@
 import json
 from logging import Logger
 from pathlib import Path
+from typing import List
 
 import grpc
-from numerous_api_client.python_protos.spm_pb2 import BuildInfoRequest, BuildRequest, JobImageReferenceUpdate, \
-    Subscription
+from spm_pb2 import BuildInfoRequest, BuildRequest, JobImageReferenceUpdate, Subscription
 
 from ..auth import AuthenticationError, TokenAuth, login
 from ..repository import NumerousRepository
@@ -25,7 +25,7 @@ def handle_build_log_message(msg):
     return False
 
 
-def command_build(log: Logger, path: Path, commit: str, job: str = None, launch: bool = False):
+def command_build(log: Logger, path: Path, commit: str, job: str = None, launch: bool = False, tags: List[str] = None):
     path = Path.cwd() if path is None else path
     try:
         repo = NumerousRepository(path).load()
@@ -39,7 +39,7 @@ def command_build(log: Logger, path: Path, commit: str, job: str = None, launch:
 
     if repo.remote is None:
         print(red('Cannot build: No remote is configured for the repository.'))
-        print(f"Use the command {bold('numbuild config --remote <REMOTE_URL>')} to configure a remote for the "
+        print(f"Use the command {bold('numerous config --remote <REMOTE_URL>')} to configure a remote for the "
               "repository.")
         return
 
@@ -62,7 +62,8 @@ def command_build(log: Logger, path: Path, commit: str, job: str = None, launch:
         build_request = BuildRequest(
             repository=repo.remote.name,
             commit_id=commit or repo.commit,
-            launch_after_build=launch
+            launch_after_build=launch,
+            tags=tags
         )
         build_reply, _call = build_manager.LaunchBuild.with_call(build_request, credentials=call_credentials)
         build_id = build_reply.build_id
