@@ -27,7 +27,7 @@ def command_checkout(log: Logger, path: Path, scenario: ProjectScenario, commit_
 
     if repo.remote is None:
         print(red('Cannot checkout: No remote is configured for the repository.'))
-        print(f"Use the command {bold('numbuild config --remote <REMOTE_URL>')} to configure a remote for the "
+        print(f"Use the command {bold('numerous config --remote <REMOTE_URL>')} to configure a remote for the "
               "repository.")
         return
 
