@@ -4,11 +4,11 @@ from pathlib import Path
 
 import grpc
 import requests
-from numerous_api_client.python_protos.spm_pb2 import HistoryRequest, PullRequest
+from spm_pb2 import HistoryRequest, PullRequest
 
 from ..auth import AuthenticationError, TokenAuth, login
 from ..repository import NumerousRepository, ProjectScenario, RepositoryRemote
-from ..utils import bold, cyan, extract_gzipped_tarball, get_build_manager, green, red
+from ..utils import bold, cyan, extract_gzipped_tarball, get_build_manager, green, print_repository_help_message, red
 
 
 def cleanup(path: Path):
@@ -18,7 +18,7 @@ def cleanup(path: Path):
 
 
 def command_clone(log: Logger, scenario: ProjectScenario, path: Path, remote: RepositoryRemote):
-    path = path or Path.cwd()
+    path = path or (Path.cwd() / remote.name)
 
     if path.exists():
         print(red(f'Cannot clone: {bold(path)} already exists'))
@@ -55,7 +55,7 @@ def command_clone(log: Logger, scenario: ProjectScenario, path: Path, remote: Re
         repo.snapshot = commit.snapshot_id
         repo.scenario = ProjectScenario(scenario_id=commit.scenario_id, project_id=commit.project_id)
 
-        print(cyan(f'Downloading snapshot {bold(repo.snapshot)} into {bold(path)}'))
+        print(cyan(f'Downloading snapshot {bold(repo.snapshot)} into {bold(path.absolute())}'))
         pull_request = PullRequest(repository=repo.remote.name, snapshot_id=commit.snapshot_id)
         snapshot_reply, _call = build_manager.PullSnapshot.with_call(pull_request, credentials=call_credentials)
         response = requests.get(snapshot_reply.archive_url.url, allow_redirects=True)
@@ -63,4 +63,6 @@ def command_clone(log: Logger, scenario: ProjectScenario, path: Path, remote: Re
 
         repo.commit = commit.id
         repo.save()
-        print(green(f"Repository {bold(repo.remote.name)} was cloned into {bold(path)}"))
+        abs_path = path.absolute()
+        print(green(f"Repository {bold(repo.remote.name)} was cloned into {bold(abs_path)}"))
+        print_repository_help_message(abs_path)
