@@ -2,7 +2,7 @@ from logging import Logger
 from pathlib import Path
 
 from ..repository import NumerousRepository
-from ..utils import bold, green, red
+from ..utils import bold, green, print_repository_help_message, red
 
 
 def command_init(log: Logger, path: Path):
@@ -26,6 +26,6 @@ def command_init(log: Logger, path: Path):
 
     repo = NumerousRepository(path).save()
 
-    print(green(f"New repository {bold(path.name)}"))
-    print(f" - Connect a remote with {bold('numbuild config --remote <REMOTE URL>')}")
-    print(f" - Checkout a scenario with {bold('numbuild checkout --scenario <SCENARIO ID>')}")
+    abs_path = Path(path.name).absolute()
+    print(green(f"Initialized new repository in {bold(abs_path)}"))
+    print_repository_help_message(abs_path)
