@@ -53,14 +53,14 @@ def command_log(log: Logger, path: Path, display_mode: str):
 
     if repo.remote is None:
         print(red('Cannot get logs: No remote is configured for the repository.'))
-        print(f"Use the command {bold('numbuild config --remote <REMOTE_URL>')} to configure a remote for the "
+        print(f"Use the command {bold('numerous config --remote <REMOTE_URL>')} to configure a remote for the "
               "repository.")
         return
 
     if repo.scenario is None:
         print(red("Cannot get logs: A scenario must be checked out."))
-        print(f"- Push to a scenario with {bold('numbuild push -c <COMMENT> <SCENARIO ID>')}")
-        print(f"- Check out a scenario with {bold('numbuild checkout <SCENARIO ID>')}")
+        print(f"Check out a scenario with {bold('numerous checkout <SCENARIO ID>')}")
+        print(f"Push to a scenario with {bold('numerous push -c <COMMENT> <SCENARIO ID>')}")
         return
 
     try:
