@@ -18,13 +18,13 @@ def command_login(log: Logger, path: Path, admin: bool):
 
     if repo.remote is None:
         print(red('Cannot login: No remote is configured for the repository.'))
-        print(f"Use the command {bold('numbuild config --remote <REMOTE_URL>')} to configure a remote for the "
+        print(f"Use the command {bold('numerous config --remote <REMOTE_URL>')} to configure a remote for the "
               "repository.")
         return
 
     if repo.scenario is None:
         print(red("Cannot re-login: A scenario must be checked out."))
-        print(f"- Check out a scenario with {bold('numbuild checkout <SCENARIO ID>')}")
+        print(f"Check out a scenario with {bold('numerous checkout <SCENARIO ID>')}")
         return
 
     repo.token = None
