@@ -46,7 +46,7 @@ def command_push(log: Logger, path: Path, comment: str):
 
     if repo.remote is None:
         print(red('Cannot push: No remote is configured for the repository.'))
-        print(f"Use the command {bold('numbuild config --remote <REMOTE_URL>')} to configure a remote for the "
+        print(f"Use the command {bold('numerous config --remote <REMOTE_URL>')} to configure a remote for the "
               "repository.")
         return
 
